transformer

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 11, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Class

type Class string

func (*Class) Name

func (c *Class) Name() string

func (*Class) Version

func (c *Class) Version() string

type Factory

type Factory struct{}

Factory returns a list of transformers from a list of string identifiers

func (*Factory) Get

func (tf *Factory) Get(c Class) (Transformer, error)

Get returns

type Info

type Info struct {
	Identifier string
	Version    string
	Hashes     map[string]string
}

type InputRecord

type InputRecord struct {
	Type     attestation.PredicateType
	Subjects attestation.Subject
	Hashes   map[string]string
}

InputRecord records the inputs that went into a predicate transformation process.

type OutputRecord

type OutputRecord struct {
	Hashes map[string]string
	Type   attestation.PredicateType
}

OutputRecord is a struct that catpures metadata about the outputs resulting from a tranformer run.

type Record

type Record struct {
	Date        *time.Time
	Transformer Info
	Inputs      []InputRecord
	Output      []OutputRecord
}

Record is a struct that records a run of a transformer.

type Transformer

type Transformer interface {
	Mutate(attestation.Subject, []attestation.Predicate) (attestation.Subject, []attestation.Predicate, error)
}

Transformer is an interface that models a predicate transformer

Directories

Path Synopsis
Package vex is a transformer that reads in a vulnerability report and a number of VEX documents and suppresses those that do not affect the subject
Package vex is a transformer that reads in a vulnerability report and a number of VEX documents and suppresses those that do not affect the subject

Jump to